diff --git a/osu-framework b/osu-framework
index e1ac6316aa..fa44e5a47e 160000
--- a/osu-framework
+++ b/osu-framework
@@ -1 +1 @@
-Subproject commit e1ac6316aa3862efb8e79e585a7b4c901a4e1b3c
+Subproject commit fa44e5a47e20956b12e598e85159a1a25b500b3c
diff --git a/osu.Desktop.VisualTests/Tests/TestCaseOptions.cs b/osu.Desktop.VisualTests/Tests/TestCaseSettings.cs
similarity index 54%
rename from osu.Desktop.VisualTests/Tests/TestCaseOptions.cs
rename to osu.Desktop.VisualTests/Tests/TestCaseSettings.cs
index ff6bdc8a5a..660085e558 100644
--- a/osu.Desktop.VisualTests/Tests/TestCaseOptions.cs
+++ b/osu.Desktop.VisualTests/Tests/TestCaseSettings.cs
@@ -6,18 +6,18 @@ using osu.Game.Overlays;
namespace osu.Desktop.VisualTests.Tests
{
- internal class TestCaseOptions : TestCase
+ internal class TestCaseSettings : TestCase
{
- public override string Description => @"Tests the options overlay";
+ public override string Description => @"Tests the settings overlay";
- private OptionsOverlay options;
+ private SettingsOverlay settings;
public override void Reset()
{
base.Reset();
- Children = new[] { options = new OptionsOverlay() };
- options.ToggleVisibility();
+ Children = new[] { settings = new SettingsOverlay() };
+ settings.ToggleVisibility();
}
}
}
diff --git a/osu.Desktop.VisualTests/osu.Desktop.VisualTests.csproj b/osu.Desktop.VisualTests/osu.Desktop.VisualTests.csproj
index 66cad48964..9b07ebf90b 100644
--- a/osu.Desktop.VisualTests/osu.Desktop.VisualTests.csproj
+++ b/osu.Desktop.VisualTests/osu.Desktop.VisualTests.csproj
@@ -211,7 +211,7 @@
-
+
diff --git a/osu.Game.Rulesets.Osu/Objects/Drawables/Pieces/SliderBody.cs b/osu.Game.Rulesets.Osu/Objects/Drawables/Pieces/SliderBody.cs
index b23fdde4e8..8b9441ea65 100644
--- a/osu.Game.Rulesets.Osu/Objects/Drawables/Pieces/SliderBody.cs
+++ b/osu.Game.Rulesets.Osu/Objects/Drawables/Pieces/SliderBody.cs
@@ -97,8 +97,8 @@ namespace osu.Game.Rulesets.Osu.Objects.Drawables.Pieces
[BackgroundDependencyLoader]
private void load(OsuConfigManager config)
{
- snakingIn = config.GetBindable(OsuConfig.SnakingInSliders);
- snakingOut = config.GetBindable(OsuConfig.SnakingOutSliders);
+ snakingIn = config.GetBindable(OsuSetting.SnakingInSliders);
+ snakingOut = config.GetBindable(OsuSetting.SnakingOutSliders);
reloadTexture();
}
diff --git a/osu.Game/Configuration/OsuConfigManager.cs b/osu.Game/Configuration/OsuConfigManager.cs
index ba19d8592a..14f83ed11f 100644
--- a/osu.Game/Configuration/OsuConfigManager.cs
+++ b/osu.Game/Configuration/OsuConfigManager.cs
@@ -8,71 +8,71 @@ using osu.Game.Screens.Select;
namespace osu.Game.Configuration
{
- public class OsuConfigManager : ConfigManager
+ public class OsuConfigManager : ConfigManager
{
protected override void InitialiseDefaults()
{
// UI/selection defaults
- Set(OsuConfig.Ruleset, 0, 0, int.MaxValue);
- Set(OsuConfig.BeatmapDetailTab, BeatmapDetailTab.Details);
+ Set(OsuSetting.Ruleset, 0, 0, int.MaxValue);
+ Set(OsuSetting.BeatmapDetailTab, BeatmapDetailTab.Details);
- Set(OsuConfig.DisplayStarsMinimum, 0.0, 0, 10);
- Set(OsuConfig.DisplayStarsMaximum, 10.0, 0, 10);
+ Set(OsuSetting.DisplayStarsMinimum, 0.0, 0, 10);
+ Set(OsuSetting.DisplayStarsMaximum, 10.0, 0, 10);
- Set(OsuConfig.ChatDisplayHeight, ChatOverlay.DEFAULT_HEIGHT, 0.2, 1);
+ Set(OsuSetting.ChatDisplayHeight, ChatOverlay.DEFAULT_HEIGHT, 0.2, 1);
// Online settings
- Set(OsuConfig.Username, string.Empty);
- Set(OsuConfig.Token, string.Empty);
+ Set(OsuSetting.Username, string.Empty);
+ Set(OsuSetting.Token, string.Empty);
- Set(OsuConfig.SavePassword, false).ValueChanged += val =>
+ Set(OsuSetting.SavePassword, false).ValueChanged += val =>
{
- if (val) Set(OsuConfig.SaveUsername, true);
+ if (val) Set(OsuSetting.SaveUsername, true);
};
- Set(OsuConfig.SaveUsername, true).ValueChanged += val =>
+ Set(OsuSetting.SaveUsername, true).ValueChanged += val =>
{
- if (!val) Set(OsuConfig.SavePassword, false);
+ if (!val) Set(OsuSetting.SavePassword, false);
};
// Audio
- Set(OsuConfig.AudioDevice, string.Empty);
+ Set(OsuSetting.AudioDevice, string.Empty);
- Set(OsuConfig.MenuVoice, true);
- Set(OsuConfig.MenuMusic, true);
+ Set(OsuSetting.MenuVoice, true);
+ Set(OsuSetting.MenuMusic, true);
- Set(OsuConfig.AudioOffset, 0, -500.0, 500.0);
+ Set(OsuSetting.AudioOffset, 0, -500.0, 500.0);
// Input
- Set(OsuConfig.MenuCursorSize, 1.0, 0.5f, 2);
- Set(OsuConfig.GameplayCursorSize, 1.0, 0.5f, 2);
+ Set(OsuSetting.MenuCursorSize, 1.0, 0.5f, 2);
+ Set(OsuSetting.GameplayCursorSize, 1.0, 0.5f, 2);
- Set(OsuConfig.MouseDisableButtons, false);
- Set(OsuConfig.MouseDisableWheel, false);
+ Set(OsuSetting.MouseDisableButtons, false);
+ Set(OsuSetting.MouseDisableWheel, false);
// Graphics
- Set(OsuConfig.ShowFpsDisplay, false);
+ Set(OsuSetting.ShowFpsDisplay, false);
- Set(OsuConfig.MenuParallax, true);
+ Set(OsuSetting.MenuParallax, true);
- Set(OsuConfig.SnakingInSliders, true);
- Set(OsuConfig.SnakingOutSliders, true);
+ Set(OsuSetting.SnakingInSliders, true);
+ Set(OsuSetting.SnakingOutSliders, true);
// Gameplay
- Set(OsuConfig.DimLevel, 0.3, 0, 1);
+ Set(OsuSetting.DimLevel, 0.3, 0, 1);
- Set(OsuConfig.ShowInterface, true);
- Set(OsuConfig.KeyOverlay, false);
+ Set(OsuSetting.ShowInterface, true);
+ Set(OsuSetting.KeyOverlay, false);
// Update
- Set(OsuConfig.ReleaseStream, ReleaseStream.Lazer);
+ Set(OsuSetting.ReleaseStream, ReleaseStream.Lazer);
}
public OsuConfigManager(Storage storage) : base(storage)
@@ -80,7 +80,7 @@ namespace osu.Game.Configuration
}
}
- public enum OsuConfig
+ public enum OsuSetting
{
Ruleset,
Token,
diff --git a/osu.Game/Graphics/Containers/ParallaxContainer.cs b/osu.Game/Graphics/Containers/ParallaxContainer.cs
index 8352656f8e..2d5952a3ce 100644
--- a/osu.Game/Graphics/Containers/ParallaxContainer.cs
+++ b/osu.Game/Graphics/Containers/ParallaxContainer.cs
@@ -39,7 +39,7 @@ namespace osu.Game.Graphics.Containers
private void load(UserInputManager input, OsuConfigManager config)
{
this.input = input;
- parallaxEnabled = config.GetBindable(OsuConfig.MenuParallax);
+ parallaxEnabled = config.GetBindable(OsuSetting.MenuParallax);
parallaxEnabled.ValueChanged += delegate
{
if (!parallaxEnabled)
diff --git a/osu.Game/Graphics/Cursor/GameplayCursor.cs b/osu.Game/Graphics/Cursor/GameplayCursor.cs
index 3f699219a4..dcdbe675b4 100644
--- a/osu.Game/Graphics/Cursor/GameplayCursor.cs
+++ b/osu.Game/Graphics/Cursor/GameplayCursor.cs
@@ -114,7 +114,7 @@ namespace osu.Game.Graphics.Cursor
},
};
- cursorScale = config.GetBindable(OsuConfig.GameplayCursorSize);
+ cursorScale = config.GetBindable(OsuSetting.GameplayCursorSize);
cursorScale.ValueChanged += newScale => cursorContainer.Scale = new Vector2((float)cursorScale);
cursorScale.TriggerChange();
}
diff --git a/osu.Game/Graphics/Cursor/MenuCursor.cs b/osu.Game/Graphics/Cursor/MenuCursor.cs
index 8d5f95aad5..b48ab879a6 100644
--- a/osu.Game/Graphics/Cursor/MenuCursor.cs
+++ b/osu.Game/Graphics/Cursor/MenuCursor.cs
@@ -128,7 +128,7 @@ namespace osu.Game.Graphics.Cursor
}
};
- cursorScale = config.GetBindable(OsuConfig.MenuCursorSize);
+ cursorScale = config.GetBindable(OsuSetting.MenuCursorSize);
cursorScale.ValueChanged += newScale => cursorContainer.Scale = new Vector2((float)newScale);
cursorScale.TriggerChange();
}
diff --git a/osu.Game/OsuGame.cs b/osu.Game/OsuGame.cs
index a84333df8c..9ce725661b 100644
--- a/osu.Game/OsuGame.cs
+++ b/osu.Game/OsuGame.cs
@@ -62,14 +62,14 @@ namespace osu.Game
private readonly string[] args;
- private OptionsOverlay options;
+ private SettingsOverlay settings;
public OsuGame(string[] args = null)
{
this.args = args;
}
- public void ToggleOptions() => options.ToggleVisibility();
+ public void ToggleSettings() => settings.ToggleVisibility();
[BackgroundDependencyLoader]
private void load()
@@ -88,7 +88,7 @@ namespace osu.Game
Dependencies.Cache(this);
- configRuleset = LocalConfig.GetBindable(OsuConfig.Ruleset);
+ configRuleset = LocalConfig.GetBindable(OsuSetting.Ruleset);
Ruleset.Value = RulesetDatabase.GetRuleset(configRuleset.Value);
Ruleset.ValueChanged += r => configRuleset.Value = r.ID ?? 0;
}
@@ -161,7 +161,7 @@ namespace osu.Game
//overlay elements
LoadComponentAsync(chat = new ChatOverlay { Depth = -1 }, mainContent.Add);
- LoadComponentAsync(options = new OptionsOverlay { Depth = -1 }, overlayContent.Add);
+ LoadComponentAsync(settings = new SettingsOverlay { Depth = -1 }, overlayContent.Add);
LoadComponentAsync(musicController = new MusicController
{
Depth = -2,
@@ -192,7 +192,7 @@ namespace osu.Game
});
};
- Dependencies.Cache(options);
+ Dependencies.Cache(settings);
Dependencies.Cache(chat);
Dependencies.Cache(musicController);
Dependencies.Cache(notificationManager);
@@ -204,15 +204,15 @@ namespace osu.Game
OnHome = delegate { intro?.ChildScreen?.MakeCurrent(); },
}, overlayContent.Add);
- options.StateChanged += delegate
+ settings.StateChanged += delegate
{
- switch (options.State)
+ switch (settings.State)
{
case Visibility.Hidden:
- intro.MoveToX(0, OptionsOverlay.TRANSITION_LENGTH, EasingTypes.OutQuint);
+ intro.MoveToX(0, SettingsOverlay.TRANSITION_LENGTH, EasingTypes.OutQuint);
break;
case Visibility.Visible:
- intro.MoveToX(OptionsOverlay.SIDEBAR_WIDTH / 2, OptionsOverlay.TRANSITION_LENGTH, EasingTypes.OutQuint);
+ intro.MoveToX(SettingsOverlay.SIDEBAR_WIDTH / 2, SettingsOverlay.TRANSITION_LENGTH, EasingTypes.OutQuint);
break;
}
};
@@ -247,7 +247,7 @@ namespace osu.Game
Toolbar.ToggleVisibility();
return true;
case Key.O:
- options.ToggleVisibility();
+ settings.ToggleVisibility();
return true;
}
}
@@ -276,7 +276,7 @@ namespace osu.Game
//central game screen change logic.
if (!currentScreen.ShowOverlays)
{
- options.State = Visibility.Hidden;
+ settings.State = Visibility.Hidden;
Toolbar.State = Visibility.Hidden;
musicController.State = Visibility.Hidden;
chat.State = Visibility.Hidden;
diff --git a/osu.Game/OsuGameBase.cs b/osu.Game/OsuGameBase.cs
index a814b5f125..7e16030ec3 100644
--- a/osu.Game/OsuGameBase.cs
+++ b/osu.Game/OsuGameBase.cs
@@ -125,8 +125,8 @@ namespace osu.Game
Dependencies.Cache(API = new APIAccess
{
- Username = LocalConfig.Get(OsuConfig.Username),
- Token = LocalConfig.Get(OsuConfig.Token)
+ Username = LocalConfig.Get(OsuSetting.Username),
+ Token = LocalConfig.Get(OsuSetting.Token)
});
API.Register(this);
@@ -137,7 +137,7 @@ namespace osu.Game
switch (state)
{
case APIState.Online:
- LocalConfig.Set(OsuConfig.Username, LocalConfig.Get(OsuConfig.SaveUsername) ? API.Username : string.Empty);
+ LocalConfig.Set(OsuSetting.Username, LocalConfig.Get(OsuSetting.SaveUsername) ? API.Username : string.Empty);
break;
}
}
@@ -166,7 +166,7 @@ namespace osu.Game
// TODO: This is temporary until we reimplement the local FPS display.
// It's just to allow end-users to access the framework FPS display without knowing the shortcut key.
- fpsDisplayVisible = LocalConfig.GetBindable(OsuConfig.ShowFpsDisplay);
+ fpsDisplayVisible = LocalConfig.GetBindable(OsuSetting.ShowFpsDisplay);
fpsDisplayVisible.ValueChanged += val =>
{
FrameStatisticsMode = val ? FrameStatisticsMode.Minimal : FrameStatisticsMode.None;
@@ -192,7 +192,7 @@ namespace osu.Game
//refresh token may have changed.
if (LocalConfig != null && API != null)
{
- LocalConfig.Set(OsuConfig.Token, LocalConfig.Get(OsuConfig.SavePassword) ? API.Token : string.Empty);
+ LocalConfig.Set(OsuSetting.Token, LocalConfig.Get(OsuSetting.SavePassword) ? API.Token : string.Empty);
LocalConfig.Save();
}
diff --git a/osu.Game/Overlays/ChatOverlay.cs b/osu.Game/Overlays/ChatOverlay.cs
index 15f8586125..7c5651b5ff 100644
--- a/osu.Game/Overlays/ChatOverlay.cs
+++ b/osu.Game/Overlays/ChatOverlay.cs
@@ -195,7 +195,7 @@ namespace osu.Game.Overlays
this.api = api;
api.Register(this);
- chatHeight = config.GetBindable(OsuConfig.ChatDisplayHeight);
+ chatHeight = config.GetBindable(OsuSetting.ChatDisplayHeight);
chatHeight.ValueChanged += h =>
{
Height = (float)h;
diff --git a/osu.Game/Overlays/LoginOverlay.cs b/osu.Game/Overlays/LoginOverlay.cs
index 694eba2c41..8c4a3b85c0 100644
--- a/osu.Game/Overlays/LoginOverlay.cs
+++ b/osu.Game/Overlays/LoginOverlay.cs
@@ -7,14 +7,14 @@ using osu.Framework.Graphics.Containers;
using osu.Framework.Graphics.Primitives;
using osu.Framework.Graphics.Sprites;
using osu.Game.Graphics;
-using osu.Game.Overlays.Options.Sections.General;
+using osu.Game.Overlays.Settings.Sections.General;
using OpenTK.Graphics;
namespace osu.Game.Overlays
{
internal class LoginOverlay : FocusedOverlayContainer
{
- private LoginOptions optionsSection;
+ private LoginSettings settingsSection;
private const float transition_time = 400;
@@ -42,7 +42,7 @@ namespace osu.Game.Overlays
AutoSizeEasing = EasingTypes.OutQuint,
Children = new Drawable[]
{
- optionsSection = new LoginOptions
+ settingsSection = new LoginSettings
{
Padding = new MarginPadding(10),
},
@@ -64,17 +64,17 @@ namespace osu.Game.Overlays
{
base.PopIn();
- optionsSection.Bounding = true;
+ settingsSection.Bounding = true;
FadeIn(transition_time, EasingTypes.OutQuint);
- optionsSection.TriggerFocus();
+ settingsSection.TriggerFocus();
}
protected override void PopOut()
{
base.PopOut();
- optionsSection.Bounding = false;
+ settingsSection.Bounding = false;
FadeOut(transition_time);
}
}
diff --git a/osu.Game/Overlays/Options/Sections/Audio/AudioDevicesOptions.cs b/osu.Game/Overlays/Settings/Sections/Audio/AudioDevicesSettings.cs
similarity index 88%
rename from osu.Game/Overlays/Options/Sections/Audio/AudioDevicesOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Audio/AudioDevicesSettings.cs
index e3033b876d..47f7abf571 100644
--- a/osu.Game/Overlays/Options/Sections/Audio/AudioDevicesOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Audio/AudioDevicesSettings.cs
@@ -7,14 +7,14 @@ using osu.Framework.Graphics;
using System.Collections.Generic;
using System.Linq;
-namespace osu.Game.Overlays.Options.Sections.Audio
+namespace osu.Game.Overlays.Settings.Sections.Audio
{
- public class AudioDevicesOptions : OptionsSubsection
+ public class AudioDevicesSettings : SettingsSubsection
{
protected override string Header => "Devices";
private AudioManager audio;
- private OptionDropdown dropdown;
+ private SettingsDropdown dropdown;
[BackgroundDependencyLoader]
private void load(AudioManager audio)
@@ -56,7 +56,7 @@ namespace osu.Game.Overlays.Options.Sections.Audio
Children = new Drawable[]
{
- dropdown = new OptionDropdown
+ dropdown = new SettingsDropdown
{
Bindable = audio.AudioDevice
},
diff --git a/osu.Game/Overlays/Options/Sections/Audio/MainMenuOptions.cs b/osu.Game/Overlays/Settings/Sections/Audio/MainMenuSettings.cs
similarity index 63%
rename from osu.Game/Overlays/Options/Sections/Audio/MainMenuOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Audio/MainMenuSettings.cs
index b2d1235b97..41a1bad364 100644
--- a/osu.Game/Overlays/Options/Sections/Audio/MainMenuOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Audio/MainMenuSettings.cs
@@ -4,9 +4,9 @@
using osu.Framework.Allocation;
using osu.Game.Configuration;
-namespace osu.Game.Overlays.Options.Sections.Audio
+namespace osu.Game.Overlays.Settings.Sections.Audio
{
- public class MainMenuOptions : OptionsSubsection
+ public class MainMenuSettings : SettingsSubsection
{
protected override string Header => "Main Menu";
@@ -15,15 +15,15 @@ namespace osu.Game.Overlays.Options.Sections.Audio
{
Children = new[]
{
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Interface voices",
- Bindable = config.GetBindable(OsuConfig.MenuVoice)
+ Bindable = config.GetBindable(OsuSetting.MenuVoice)
},
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "osu! music theme",
- Bindable = config.GetBindable(OsuConfig.MenuMusic)
+ Bindable = config.GetBindable(OsuSetting.MenuMusic)
},
};
}
diff --git a/osu.Game/Overlays/Options/Sections/Audio/OffsetOptions.cs b/osu.Game/Overlays/Settings/Sections/Audio/OffsetSettings.cs
similarity index 77%
rename from osu.Game/Overlays/Options/Sections/Audio/OffsetOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Audio/OffsetSettings.cs
index 72c3dd071a..bc09a2145a 100644
--- a/osu.Game/Overlays/Options/Sections/Audio/OffsetOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Audio/OffsetSettings.cs
@@ -6,9 +6,9 @@ using osu.Framework.Graphics;
using osu.Game.Configuration;
using osu.Game.Graphics.UserInterface;
-namespace osu.Game.Overlays.Options.Sections.Audio
+namespace osu.Game.Overlays.Settings.Sections.Audio
{
- public class OffsetOptions : OptionsSubsection
+ public class OffsetSettings : SettingsSubsection
{
protected override string Header => "Offset Adjustment";
@@ -17,10 +17,10 @@ namespace osu.Game.Overlays.Options.Sections.Audio
{
Children = new Drawable[]
{
- new OptionSlider
+ new SettingsSlider
{
LabelText = "Audio Offset",
- Bindable = config.GetBindable(OsuConfig.AudioOffset)
+ Bindable = config.GetBindable(OsuSetting.AudioOffset)
},
new OsuButton
{
diff --git a/osu.Game/Overlays/Options/Sections/Audio/VolumeOptions.cs b/osu.Game/Overlays/Settings/Sections/Audio/VolumeSettings.cs
similarity index 53%
rename from osu.Game/Overlays/Options/Sections/Audio/VolumeOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Audio/VolumeSettings.cs
index c3eb04da13..ea442cdfc2 100644
--- a/osu.Game/Overlays/Options/Sections/Audio/VolumeOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Audio/VolumeSettings.cs
@@ -5,9 +5,9 @@ using osu.Framework.Allocation;
using osu.Framework.Audio;
using osu.Framework.Graphics;
-namespace osu.Game.Overlays.Options.Sections.Audio
+namespace osu.Game.Overlays.Settings.Sections.Audio
{
- public class VolumeOptions : OptionsSubsection
+ public class VolumeSettings : SettingsSubsection
{
protected override string Header => "Volume";
@@ -16,9 +16,9 @@ namespace osu.Game.Overlays.Options.Sections.Audio
{
Children = new Drawable[]
{
- new OptionSlider { LabelText = "Master", Bindable = audio.Volume },
- new OptionSlider { LabelText = "Effect", Bindable = audio.VolumeSample },
- new OptionSlider { LabelText = "Music", Bindable = audio.VolumeTrack },
+ new SettingsSlider { LabelText = "Master", Bindable = audio.Volume },
+ new SettingsSlider { LabelText = "Effect", Bindable = audio.VolumeSample },
+ new SettingsSlider { LabelText = "Music", Bindable = audio.VolumeTrack },
};
}
}
diff --git a/osu.Game/Overlays/Options/Sections/AudioSection.cs b/osu.Game/Overlays/Settings/Sections/AudioSection.cs
similarity index 58%
rename from osu.Game/Overlays/Options/Sections/AudioSection.cs
rename to osu.Game/Overlays/Settings/Sections/AudioSection.cs
index a9f8265a68..c994a6296c 100644
--- a/osu.Game/Overlays/Options/Sections/AudioSection.cs
+++ b/osu.Game/Overlays/Settings/Sections/AudioSection.cs
@@ -3,11 +3,11 @@
using osu.Framework.Graphics;
using osu.Game.Graphics;
-using osu.Game.Overlays.Options.Sections.Audio;
+using osu.Game.Overlays.Settings.Sections.Audio;
-namespace osu.Game.Overlays.Options.Sections
+namespace osu.Game.Overlays.Settings.Sections
{
- public class AudioSection : OptionsSection
+ public class AudioSection : SettingsSection
{
public override string Header => "Audio";
public override FontAwesome Icon => FontAwesome.fa_headphones;
@@ -16,10 +16,10 @@ namespace osu.Game.Overlays.Options.Sections
{
Children = new Drawable[]
{
- new AudioDevicesOptions(),
- new VolumeOptions(),
- new OffsetOptions(),
- new MainMenuOptions(),
+ new AudioDevicesSettings(),
+ new VolumeSettings(),
+ new OffsetSettings(),
+ new MainMenuSettings(),
};
}
}
diff --git a/osu.Game/Overlays/Options/Sections/Debug/GCOptions.cs b/osu.Game/Overlays/Settings/Sections/Debug/GCSettings.cs
similarity index 83%
rename from osu.Game/Overlays/Options/Sections/Debug/GCOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Debug/GCSettings.cs
index 4350625d51..29b96a59c2 100644
--- a/osu.Game/Overlays/Options/Sections/Debug/GCOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Debug/GCSettings.cs
@@ -8,9 +8,9 @@ using osu.Framework.Configuration;
using osu.Framework.Graphics;
using osu.Game.Graphics.UserInterface;
-namespace osu.Game.Overlays.Options.Sections.Debug
+namespace osu.Game.Overlays.Settings.Sections.Debug
{
- public class GCOptions : OptionsSubsection
+ public class GCSettings : SettingsSubsection
{
protected override string Header => "Garbage Collector";
@@ -19,7 +19,7 @@ namespace osu.Game.Overlays.Options.Sections.Debug
{
Children = new Drawable[]
{
- new OptionEnumDropdown
+ new SettingsEnumDropdown
{
LabelText = "Active mode",
Bindable = config.GetBindable(FrameworkDebugConfig.ActiveGCMode)
diff --git a/osu.Game/Overlays/Options/Sections/Debug/GeneralOptions.cs b/osu.Game/Overlays/Settings/Sections/Debug/GeneralSettings.cs
similarity index 80%
rename from osu.Game/Overlays/Options/Sections/Debug/GeneralOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Debug/GeneralSettings.cs
index 9258b8fbeb..9fbb4011b7 100644
--- a/osu.Game/Overlays/Options/Sections/Debug/GeneralOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Debug/GeneralSettings.cs
@@ -5,9 +5,9 @@ using osu.Framework.Allocation;
using osu.Framework.Configuration;
using osu.Framework.Graphics;
-namespace osu.Game.Overlays.Options.Sections.Debug
+namespace osu.Game.Overlays.Settings.Sections.Debug
{
- public class GeneralOptions : OptionsSubsection
+ public class GeneralSettings : SettingsSubsection
{
protected override string Header => "General";
@@ -16,7 +16,7 @@ namespace osu.Game.Overlays.Options.Sections.Debug
{
Children = new Drawable[]
{
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Bypass caching",
Bindable = config.GetBindable(FrameworkDebugConfig.BypassCaching)
diff --git a/osu.Game/Overlays/Options/Sections/DebugSection.cs b/osu.Game/Overlays/Settings/Sections/DebugSection.cs
similarity index 65%
rename from osu.Game/Overlays/Options/Sections/DebugSection.cs
rename to osu.Game/Overlays/Settings/Sections/DebugSection.cs
index a90558a319..05b7171eed 100644
--- a/osu.Game/Overlays/Options/Sections/DebugSection.cs
+++ b/osu.Game/Overlays/Settings/Sections/DebugSection.cs
@@ -3,11 +3,11 @@
using osu.Framework.Graphics;
using osu.Game.Graphics;
-using osu.Game.Overlays.Options.Sections.Debug;
+using osu.Game.Overlays.Settings.Sections.Debug;
-namespace osu.Game.Overlays.Options.Sections
+namespace osu.Game.Overlays.Settings.Sections
{
- public class DebugSection : OptionsSection
+ public class DebugSection : SettingsSection
{
public override string Header => "Debug";
public override FontAwesome Icon => FontAwesome.fa_bug;
@@ -16,8 +16,8 @@ namespace osu.Game.Overlays.Options.Sections
{
Children = new Drawable[]
{
- new GeneralOptions(),
- new GCOptions(),
+ new GeneralSettings(),
+ new GCSettings(),
};
}
}
diff --git a/osu.Game/Overlays/Options/Sections/Gameplay/GeneralOptions.cs b/osu.Game/Overlays/Settings/Sections/Gameplay/GeneralSettings.cs
similarity index 60%
rename from osu.Game/Overlays/Options/Sections/Gameplay/GeneralOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Gameplay/GeneralSettings.cs
index 2598d95949..a8ec04514a 100644
--- a/osu.Game/Overlays/Options/Sections/Gameplay/GeneralOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Gameplay/GeneralSettings.cs
@@ -5,9 +5,9 @@ using osu.Framework.Allocation;
using osu.Framework.Graphics;
using osu.Game.Configuration;
-namespace osu.Game.Overlays.Options.Sections.Gameplay
+namespace osu.Game.Overlays.Settings.Sections.Gameplay
{
- public class GeneralOptions : OptionsSubsection
+ public class GeneralSettings : SettingsSubsection
{
protected override string Header => "General";
@@ -16,20 +16,20 @@ namespace osu.Game.Overlays.Options.Sections.Gameplay
{
Children = new Drawable[]
{
- new OptionSlider
+ new SettingsSlider
{
LabelText = "Background dim",
- Bindable = config.GetBindable(OsuConfig.DimLevel)
+ Bindable = config.GetBindable(OsuSetting.DimLevel)
},
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Show score overlay",
- Bindable = config.GetBindable(OsuConfig.ShowInterface)
+ Bindable = config.GetBindable(OsuSetting.ShowInterface)
},
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Always show key overlay",
- Bindable = config.GetBindable(OsuConfig.KeyOverlay)
+ Bindable = config.GetBindable(OsuSetting.KeyOverlay)
},
};
}
diff --git a/osu.Game/Overlays/Options/Sections/Gameplay/SongSelectOptions.cs b/osu.Game/Overlays/Settings/Sections/Gameplay/SongSelectSettings.cs
similarity index 66%
rename from osu.Game/Overlays/Options/Sections/Gameplay/SongSelectOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Gameplay/SongSelectSettings.cs
index 910eae9a5a..7626911627 100644
--- a/osu.Game/Overlays/Options/Sections/Gameplay/SongSelectOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Gameplay/SongSelectSettings.cs
@@ -6,9 +6,9 @@ using osu.Framework.Graphics;
using osu.Game.Configuration;
using osu.Game.Graphics.UserInterface;
-namespace osu.Game.Overlays.Options.Sections.Gameplay
+namespace osu.Game.Overlays.Settings.Sections.Gameplay
{
- public class SongSelectOptions : OptionsSubsection
+ public class SongSelectSettings : SettingsSubsection
{
protected override string Header => "Song Select";
@@ -17,15 +17,15 @@ namespace osu.Game.Overlays.Options.Sections.Gameplay
{
Children = new Drawable[]
{
- new OptionSlider
+ new SettingsSlider
{
LabelText = "Display beatmaps from",
- Bindable = config.GetBindable(OsuConfig.DisplayStarsMinimum)
+ Bindable = config.GetBindable(OsuSetting.DisplayStarsMinimum)
},
- new OptionSlider
+ new SettingsSlider
{
LabelText = "up to",
- Bindable = config.GetBindable(OsuConfig.DisplayStarsMaximum)
+ Bindable = config.GetBindable(OsuSetting.DisplayStarsMaximum)
},
};
}
diff --git a/osu.Game/Overlays/Options/Sections/GameplaySection.cs b/osu.Game/Overlays/Settings/Sections/GameplaySection.cs
similarity index 64%
rename from osu.Game/Overlays/Options/Sections/GameplaySection.cs
rename to osu.Game/Overlays/Settings/Sections/GameplaySection.cs
index 85a180ccbc..be957912c1 100644
--- a/osu.Game/Overlays/Options/Sections/GameplaySection.cs
+++ b/osu.Game/Overlays/Settings/Sections/GameplaySection.cs
@@ -3,11 +3,11 @@
using osu.Framework.Graphics;
using osu.Game.Graphics;
-using osu.Game.Overlays.Options.Sections.Gameplay;
+using osu.Game.Overlays.Settings.Sections.Gameplay;
-namespace osu.Game.Overlays.Options.Sections
+namespace osu.Game.Overlays.Settings.Sections
{
- public class GameplaySection : OptionsSection
+ public class GameplaySection : SettingsSection
{
public override string Header => "Gameplay";
public override FontAwesome Icon => FontAwesome.fa_circle_o;
@@ -16,8 +16,8 @@ namespace osu.Game.Overlays.Options.Sections
{
Children = new Drawable[]
{
- new GeneralOptions(),
- new SongSelectOptions(),
+ new GeneralSettings(),
+ new SongSelectSettings(),
};
}
}
diff --git a/osu.Game/Overlays/Options/Sections/General/LanguageOptions.cs b/osu.Game/Overlays/Settings/Sections/General/LanguageSettings.cs
similarity index 77%
rename from osu.Game/Overlays/Options/Sections/General/LanguageOptions.cs
rename to osu.Game/Overlays/Settings/Sections/General/LanguageSettings.cs
index 2778f2567d..552b8bea1b 100644
--- a/osu.Game/Overlays/Options/Sections/General/LanguageOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/General/LanguageSettings.cs
@@ -5,9 +5,9 @@ using osu.Framework.Allocation;
using osu.Framework.Configuration;
using osu.Framework.Graphics;
-namespace osu.Game.Overlays.Options.Sections.General
+namespace osu.Game.Overlays.Settings.Sections.General
{
- public class LanguageOptions : OptionsSubsection
+ public class LanguageSettings : SettingsSubsection
{
protected override string Header => "Language";
@@ -16,10 +16,10 @@ namespace osu.Game.Overlays.Options.Sections.General
{
Children = new Drawable[]
{
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Prefer metadata in original language",
- Bindable = frameworkConfig.GetBindable(FrameworkConfig.ShowUnicode)
+ Bindable = frameworkConfig.GetBindable(FrameworkSetting.ShowUnicode)
},
};
}
diff --git a/osu.Game/Overlays/Options/Sections/General/LoginOptions.cs b/osu.Game/Overlays/Settings/Sections/General/LoginSettings.cs
similarity index 90%
rename from osu.Game/Overlays/Options/Sections/General/LoginOptions.cs
rename to osu.Game/Overlays/Settings/Sections/General/LoginSettings.cs
index a3612a6396..86a47d8a95 100644
--- a/osu.Game/Overlays/Options/Sections/General/LoginOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/General/LoginSettings.cs
@@ -13,9 +13,9 @@ using osu.Game.Online.API;
using OpenTK;
using osu.Framework.Input;
-namespace osu.Game.Overlays.Options.Sections.General
+namespace osu.Game.Overlays.Settings.Sections.General
{
- public class LoginOptions : OptionsSubsection, IOnlineComponent
+ public class LoginSettings : SettingsSubsection, IOnlineComponent
{
private bool bounding = true;
private LoginForm form;
@@ -132,15 +132,15 @@ namespace osu.Game.Overlays.Options.Sections.General
TabbableContentContainer = this,
OnCommit = (sender, newText) => performLogin()
},
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Remember username",
- Bindable = config.GetBindable(OsuConfig.SaveUsername),
+ Bindable = config.GetBindable(OsuSetting.SaveUsername),
},
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Stay logged in",
- Bindable = config.GetBindable(OsuConfig.SavePassword),
+ Bindable = config.GetBindable(OsuSetting.SavePassword),
},
new OsuButton
{
diff --git a/osu.Game/Overlays/Options/Sections/General/UpdateOptions.cs b/osu.Game/Overlays/Settings/Sections/General/UpdateSettings.cs
similarity index 80%
rename from osu.Game/Overlays/Options/Sections/General/UpdateOptions.cs
rename to osu.Game/Overlays/Settings/Sections/General/UpdateSettings.cs
index 1d9a5a7d72..3ceb8d2ff4 100644
--- a/osu.Game/Overlays/Options/Sections/General/UpdateOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/General/UpdateSettings.cs
@@ -7,9 +7,9 @@ using osu.Framework.Platform;
using osu.Game.Configuration;
using osu.Game.Graphics.UserInterface;
-namespace osu.Game.Overlays.Options.Sections.General
+namespace osu.Game.Overlays.Settings.Sections.General
{
- public class UpdateOptions : OptionsSubsection
+ public class UpdateSettings : SettingsSubsection
{
protected override string Header => "Updates";
@@ -18,10 +18,10 @@ namespace osu.Game.Overlays.Options.Sections.General
{
Children = new Drawable[]
{
- new OptionEnumDropdown
+ new SettingsEnumDropdown
{
LabelText = "Release stream",
- Bindable = config.GetBindable(OsuConfig.ReleaseStream),
+ Bindable = config.GetBindable(OsuSetting.ReleaseStream),
},
new OsuButton
{
diff --git a/osu.Game/Overlays/Options/Sections/GeneralSection.cs b/osu.Game/Overlays/Settings/Sections/GeneralSection.cs
similarity index 64%
rename from osu.Game/Overlays/Options/Sections/GeneralSection.cs
rename to osu.Game/Overlays/Settings/Sections/GeneralSection.cs
index e0c447b08b..5511f827e2 100644
--- a/osu.Game/Overlays/Options/Sections/GeneralSection.cs
+++ b/osu.Game/Overlays/Settings/Sections/GeneralSection.cs
@@ -3,11 +3,11 @@
using osu.Framework.Graphics;
using osu.Game.Graphics;
-using osu.Game.Overlays.Options.Sections.General;
+using osu.Game.Overlays.Settings.Sections.General;
-namespace osu.Game.Overlays.Options.Sections
+namespace osu.Game.Overlays.Settings.Sections
{
- public class GeneralSection : OptionsSection
+ public class GeneralSection : SettingsSection
{
public override string Header => "General";
public override FontAwesome Icon => FontAwesome.fa_gear;
@@ -16,8 +16,8 @@ namespace osu.Game.Overlays.Options.Sections
{
Children = new Drawable[]
{
- new LanguageOptions(),
- new UpdateOptions(),
+ new LanguageSettings(),
+ new UpdateSettings(),
};
}
}
diff --git a/osu.Game/Overlays/Options/Sections/Graphics/DetailOptions.cs b/osu.Game/Overlays/Settings/Sections/Graphics/DetailSettings.cs
similarity index 64%
rename from osu.Game/Overlays/Options/Sections/Graphics/DetailOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Graphics/DetailSettings.cs
index 6503a7ea90..78eab6ebd8 100644
--- a/osu.Game/Overlays/Options/Sections/Graphics/DetailOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Graphics/DetailSettings.cs
@@ -5,9 +5,9 @@ using osu.Framework.Allocation;
using osu.Framework.Graphics;
using osu.Game.Configuration;
-namespace osu.Game.Overlays.Options.Sections.Graphics
+namespace osu.Game.Overlays.Settings.Sections.Graphics
{
- public class DetailOptions : OptionsSubsection
+ public class DetailSettings : SettingsSubsection
{
protected override string Header => "Detail Settings";
@@ -16,15 +16,15 @@ namespace osu.Game.Overlays.Options.Sections.Graphics
{
Children = new Drawable[]
{
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Snaking in sliders",
- Bindable = config.GetBindable(OsuConfig.SnakingInSliders)
+ Bindable = config.GetBindable(OsuSetting.SnakingInSliders)
},
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Snaking out sliders",
- Bindable = config.GetBindable(OsuConfig.SnakingOutSliders)
+ Bindable = config.GetBindable(OsuSetting.SnakingOutSliders)
},
};
}
diff --git a/osu.Game/Overlays/Options/Sections/Graphics/LayoutOptions.cs b/osu.Game/Overlays/Settings/Sections/Graphics/LayoutSettings.cs
similarity index 70%
rename from osu.Game/Overlays/Options/Sections/Graphics/LayoutOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Graphics/LayoutSettings.cs
index 1b4b0b3c7d..9a5fd769cd 100644
--- a/osu.Game/Overlays/Options/Sections/Graphics/LayoutOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Graphics/LayoutSettings.cs
@@ -5,43 +5,43 @@ using osu.Framework.Allocation;
using osu.Framework.Configuration;
using osu.Framework.Graphics;
-namespace osu.Game.Overlays.Options.Sections.Graphics
+namespace osu.Game.Overlays.Settings.Sections.Graphics
{
- public class LayoutOptions : OptionsSubsection
+ public class LayoutSettings : SettingsSubsection
{
protected override string Header => "Layout";
- private OptionSlider letterboxPositionX;
- private OptionSlider letterboxPositionY;
+ private SettingsSlider letterboxPositionX;
+ private SettingsSlider letterboxPositionY;
private Bindable letterboxing;
[BackgroundDependencyLoader]
private void load(FrameworkConfigManager config)
{
- letterboxing = config.GetBindable(FrameworkConfig.Letterboxing);
+ letterboxing = config.GetBindable(FrameworkSetting.Letterboxing);
Children = new Drawable[]
{
- new OptionEnumDropdown
+ new SettingsEnumDropdown
{
LabelText = "Screen mode",
- Bindable = config.GetBindable(FrameworkConfig.WindowMode),
+ Bindable = config.GetBindable(FrameworkSetting.WindowMode),
},
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Letterboxing",
Bindable = letterboxing,
},
- letterboxPositionX = new OptionSlider
+ letterboxPositionX = new SettingsSlider
{
LabelText = "Horizontal position",
- Bindable = config.GetBindable(FrameworkConfig.LetterboxPositionX)
+ Bindable = config.GetBindable(FrameworkSetting.LetterboxPositionX)
},
- letterboxPositionY = new OptionSlider
+ letterboxPositionY = new SettingsSlider
{
LabelText = "Vertical position",
- Bindable = config.GetBindable(FrameworkConfig.LetterboxPositionY)
+ Bindable = config.GetBindable(FrameworkSetting.LetterboxPositionY)
},
};
diff --git a/osu.Game/Overlays/Options/Sections/Graphics/MainMenuOptions.cs b/osu.Game/Overlays/Settings/Sections/Graphics/MainMenuSettings.cs
similarity index 68%
rename from osu.Game/Overlays/Options/Sections/Graphics/MainMenuOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Graphics/MainMenuSettings.cs
index 6ebb8f263d..7fe5be2fa1 100644
--- a/osu.Game/Overlays/Options/Sections/Graphics/MainMenuOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Graphics/MainMenuSettings.cs
@@ -4,9 +4,9 @@
using osu.Framework.Allocation;
using osu.Game.Configuration;
-namespace osu.Game.Overlays.Options.Sections.Graphics
+namespace osu.Game.Overlays.Settings.Sections.Graphics
{
- public class MainMenuOptions : OptionsSubsection
+ public class MainMenuSettings : SettingsSubsection
{
protected override string Header => "User Interface";
@@ -15,10 +15,10 @@ namespace osu.Game.Overlays.Options.Sections.Graphics
{
Children = new[]
{
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Parallax",
- Bindable = config.GetBindable(OsuConfig.MenuParallax)
+ Bindable = config.GetBindable(OsuSetting.MenuParallax)
},
};
}
diff --git a/osu.Game/Overlays/Options/Sections/Graphics/RendererOptions.cs b/osu.Game/Overlays/Settings/Sections/Graphics/RendererSettings.cs
similarity index 72%
rename from osu.Game/Overlays/Options/Sections/Graphics/RendererOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Graphics/RendererSettings.cs
index f11c18d3b4..8e84a25bb9 100644
--- a/osu.Game/Overlays/Options/Sections/Graphics/RendererOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Graphics/RendererSettings.cs
@@ -6,9 +6,9 @@ using osu.Framework.Configuration;
using osu.Framework.Graphics;
using osu.Game.Configuration;
-namespace osu.Game.Overlays.Options.Sections.Graphics
+namespace osu.Game.Overlays.Settings.Sections.Graphics
{
- public class RendererOptions : OptionsSubsection
+ public class RendererSettings : SettingsSubsection
{
protected override string Header => "Renderer";
@@ -19,15 +19,15 @@ namespace osu.Game.Overlays.Options.Sections.Graphics
Children = new Drawable[]
{
// TODO: this needs to be a custom dropdown at some point
- new OptionEnumDropdown
+ new SettingsEnumDropdown
{
LabelText = "Frame limiter",
- Bindable = config.GetBindable(FrameworkConfig.FrameSync)
+ Bindable = config.GetBindable(FrameworkSetting.FrameSync)
},
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Show FPS",
- Bindable = osuConfig.GetBindable(OsuConfig.ShowFpsDisplay)
+ Bindable = osuConfig.GetBindable(OsuSetting.ShowFpsDisplay)
},
};
}
diff --git a/osu.Game/Overlays/Options/Sections/GraphicsSection.cs b/osu.Game/Overlays/Settings/Sections/GraphicsSection.cs
similarity index 58%
rename from osu.Game/Overlays/Options/Sections/GraphicsSection.cs
rename to osu.Game/Overlays/Settings/Sections/GraphicsSection.cs
index dbbcbde2b9..f188f2476c 100644
--- a/osu.Game/Overlays/Options/Sections/GraphicsSection.cs
+++ b/osu.Game/Overlays/Settings/Sections/GraphicsSection.cs
@@ -3,11 +3,11 @@
using osu.Framework.Graphics;
using osu.Game.Graphics;
-using osu.Game.Overlays.Options.Sections.Graphics;
+using osu.Game.Overlays.Settings.Sections.Graphics;
-namespace osu.Game.Overlays.Options.Sections
+namespace osu.Game.Overlays.Settings.Sections
{
- public class GraphicsSection : OptionsSection
+ public class GraphicsSection : SettingsSection
{
public override string Header => "Graphics";
public override FontAwesome Icon => FontAwesome.fa_laptop;
@@ -16,10 +16,10 @@ namespace osu.Game.Overlays.Options.Sections
{
Children = new Drawable[]
{
- new RendererOptions(),
- new LayoutOptions(),
- new DetailOptions(),
- new MainMenuOptions(),
+ new RendererSettings(),
+ new LayoutSettings(),
+ new DetailSettings(),
+ new MainMenuSettings(),
};
}
}
diff --git a/osu.Game/Overlays/Options/Sections/Input/KeyboardOptions.cs b/osu.Game/Overlays/Settings/Sections/Input/KeyboardSettings.cs
similarity index 76%
rename from osu.Game/Overlays/Options/Sections/Input/KeyboardOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Input/KeyboardSettings.cs
index b7e8598cff..9ead4ca7a4 100644
--- a/osu.Game/Overlays/Options/Sections/Input/KeyboardOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Input/KeyboardSettings.cs
@@ -4,13 +4,13 @@
using osu.Framework.Graphics;
using osu.Game.Graphics.UserInterface;
-namespace osu.Game.Overlays.Options.Sections.Input
+namespace osu.Game.Overlays.Settings.Sections.Input
{
- public class KeyboardOptions : OptionsSubsection
+ public class KeyboardSettings : SettingsSubsection
{
protected override string Header => "Keyboard";
- public KeyboardOptions()
+ public KeyboardSettings()
{
Children = new Drawable[]
{
diff --git a/osu.Game/Overlays/Options/Sections/Input/MouseOptions.cs b/osu.Game/Overlays/Settings/Sections/Input/MouseSettings.cs
similarity index 69%
rename from osu.Game/Overlays/Options/Sections/Input/MouseOptions.cs
rename to osu.Game/Overlays/Settings/Sections/Input/MouseSettings.cs
index b4ce11e2bc..9cf5c42319 100644
--- a/osu.Game/Overlays/Options/Sections/Input/MouseOptions.cs
+++ b/osu.Game/Overlays/Settings/Sections/Input/MouseSettings.cs
@@ -8,9 +8,9 @@ using osu.Framework.Input;
using osu.Game.Configuration;
using osu.Game.Graphics.UserInterface;
-namespace osu.Game.Overlays.Options.Sections.Input
+namespace osu.Game.Overlays.Settings.Sections.Input
{
- public class MouseOptions : OptionsSubsection
+ public class MouseSettings : SettingsSubsection
{
protected override string Header => "Mouse";
@@ -19,20 +19,20 @@ namespace osu.Game.Overlays.Options.Sections.Input
{
Children = new Drawable[]
{
- new OptionEnumDropdown
+ new SettingsEnumDropdown
{
LabelText = "Confine mouse cursor",
- Bindable = config.GetBindable(FrameworkConfig.ConfineMouseMode),
+ Bindable = config.GetBindable(FrameworkSetting.ConfineMouseMode),
},
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Disable mouse wheel during gameplay",
- Bindable = osuConfig.GetBindable(OsuConfig.MouseDisableWheel)
+ Bindable = osuConfig.GetBindable(OsuSetting.MouseDisableWheel)
},
- new OptionCheckbox
+ new SettingsCheckbox
{
LabelText = "Disable mouse buttons during gameplay",
- Bindable = osuConfig.GetBindable(OsuConfig.MouseDisableButtons)
+ Bindable = osuConfig.GetBindable(OsuSetting.MouseDisableButtons)
},
};
}
diff --git a/osu.Game/Overlays/Options/Sections/InputSection.cs b/osu.Game/Overlays/Settings/Sections/InputSection.cs
similarity index 65%
rename from osu.Game/Overlays/Options/Sections/InputSection.cs
rename to osu.Game/Overlays/Settings/Sections/InputSection.cs
index d39d0a0e20..cfa3bc78f0 100644
--- a/osu.Game/Overlays/Options/Sections/InputSection.cs
+++ b/osu.Game/Overlays/Settings/Sections/InputSection.cs
@@ -3,11 +3,11 @@
using osu.Framework.Graphics;
using osu.Game.Graphics;
-using osu.Game.Overlays.Options.Sections.Input;
+using osu.Game.Overlays.Settings.Sections.Input;
-namespace osu.Game.Overlays.Options.Sections
+namespace osu.Game.Overlays.Settings.Sections
{
- public class InputSection : OptionsSection
+ public class InputSection : SettingsSection
{
public override string Header => "Input";
public override FontAwesome Icon => FontAwesome.fa_keyboard_o;
@@ -16,8 +16,8 @@ namespace osu.Game.Overlays.Options.Sections
{
Children = new Drawable[]
{
- new MouseOptions(),
- new KeyboardOptions(),
+ new MouseSettings(),
+ new KeyboardSettings(),
};
}
}
diff --git a/osu.Game/Overlays/Options/Sections/MaintenanceSection.cs b/osu.Game/Overlays/Settings/Sections/MaintenanceSection.cs
similarity index 81%
rename from osu.Game/Overlays/Options/Sections/MaintenanceSection.cs
rename to osu.Game/Overlays/Settings/Sections/MaintenanceSection.cs
index e8a4f91074..529cec79c1 100644
--- a/osu.Game/Overlays/Options/Sections/MaintenanceSection.cs
+++ b/osu.Game/Overlays/Settings/Sections/MaintenanceSection.cs
@@ -5,9 +5,9 @@ using osu.Framework.Graphics;
using osu.Game.Graphics;
using OpenTK;
-namespace osu.Game.Overlays.Options.Sections
+namespace osu.Game.Overlays.Settings.Sections
{
- public class MaintenanceSection : OptionsSection
+ public class MaintenanceSection : SettingsSection
{
public override string Header => "Maintenance";
public override FontAwesome Icon => FontAwesome.fa_wrench;
diff --git a/osu.Game/Overlays/Options/Sections/OnlineSection.cs b/osu.Game/Overlays/Settings/Sections/OnlineSection.cs
similarity index 80%
rename from osu.Game/Overlays/Options/Sections/OnlineSection.cs
rename to osu.Game/Overlays/Settings/Sections/OnlineSection.cs
index 1a65a23121..4494da1bf4 100644
--- a/osu.Game/Overlays/Options/Sections/OnlineSection.cs
+++ b/osu.Game/Overlays/Settings/Sections/OnlineSection.cs
@@ -4,9 +4,9 @@
using osu.Framework.Graphics;
using osu.Game.Graphics;
-namespace osu.Game.Overlays.Options.Sections
+namespace osu.Game.Overlays.Settings.Sections
{
- public class OnlineSection : OptionsSection
+ public class OnlineSection : SettingsSection
{
public override string Header => "Online";
public override FontAwesome Icon => FontAwesome.fa_globe;
diff --git a/osu.Game/Overlays/Options/Sections/SkinSection.cs b/osu.Game/Overlays/Settings/Sections/SkinSection.cs
similarity index 71%
rename from osu.Game/Overlays/Options/Sections/SkinSection.cs
rename to osu.Game/Overlays/Settings/Sections/SkinSection.cs
index b3c225d00c..46bc899499 100644
--- a/osu.Game/Overlays/Options/Sections/SkinSection.cs
+++ b/osu.Game/Overlays/Settings/Sections/SkinSection.cs
@@ -8,9 +8,9 @@ using osu.Game.Graphics;
using osu.Game.Graphics.UserInterface;
using OpenTK;
-namespace osu.Game.Overlays.Options.Sections
+namespace osu.Game.Overlays.Settings.Sections
{
- public class SkinSection : OptionsSection
+ public class SkinSection : SettingsSection
{
public override string Header => "Skin";
public override FontAwesome Icon => FontAwesome.fa_paint_brush;
@@ -21,15 +21,15 @@ namespace osu.Game.Overlays.Options.Sections
FlowContent.Spacing = new Vector2(0, 5);
Children = new Drawable[]
{
- new OptionSlider
+ new SettingsSlider
{
LabelText = "Menu cursor size",
- Bindable = config.GetBindable(OsuConfig.MenuCursorSize)
+ Bindable = config.GetBindable(OsuSetting.MenuCursorSize)
},
- new OptionSlider
+ new SettingsSlider
{
LabelText = "Gameplay cursor size",
- Bindable = config.GetBindable(OsuConfig.GameplayCursorSize)
+ Bindable = config.GetBindable(OsuSetting.GameplayCursorSize)
},
};
}
diff --git a/osu.Game/Overlays/Options/OptionCheckbox.cs b/osu.Game/Overlays/Settings/SettingsCheckbox.cs
similarity index 82%
rename from osu.Game/Overlays/Options/OptionCheckbox.cs
rename to osu.Game/Overlays/Settings/SettingsCheckbox.cs
index de7b138c3c..659754ce79 100644
--- a/osu.Game/Overlays/Options/OptionCheckbox.cs
+++ b/osu.Game/Overlays/Settings/SettingsCheckbox.cs
@@ -4,9 +4,9 @@
using osu.Framework.Graphics;
using osu.Game.Graphics.UserInterface;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
- public class OptionCheckbox : OptionItem
+ public class SettingsCheckbox : SettingsItem
{
private OsuCheckbox checkbox;
diff --git a/osu.Game/Overlays/Options/OptionDropdown.cs b/osu.Game/Overlays/Settings/SettingsDropdown.cs
similarity index 88%
rename from osu.Game/Overlays/Options/OptionDropdown.cs
rename to osu.Game/Overlays/Settings/SettingsDropdown.cs
index 1427eafe39..8ce755b90e 100644
--- a/osu.Game/Overlays/Options/OptionDropdown.cs
+++ b/osu.Game/Overlays/Settings/SettingsDropdown.cs
@@ -7,9 +7,9 @@ using osu.Framework.Graphics.Primitives;
using osu.Framework.Graphics.UserInterface;
using osu.Game.Graphics.UserInterface;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
- public class OptionDropdown : OptionItem
+ public class SettingsDropdown : SettingsItem
{
private Dropdown dropdown;
diff --git a/osu.Game/Overlays/Options/OptionEnumDropdown.cs b/osu.Game/Overlays/Settings/SettingsEnumDropdown.cs
similarity index 75%
rename from osu.Game/Overlays/Options/OptionEnumDropdown.cs
rename to osu.Game/Overlays/Settings/SettingsEnumDropdown.cs
index 1a4f4635e2..a9f0848403 100644
--- a/osu.Game/Overlays/Options/OptionEnumDropdown.cs
+++ b/osu.Game/Overlays/Settings/SettingsEnumDropdown.cs
@@ -6,14 +6,14 @@ using System.Reflection;
using System.ComponentModel;
using System.Collections.Generic;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
- public class OptionEnumDropdown : OptionDropdown
+ public class SettingsEnumDropdown : SettingsDropdown
{
- public OptionEnumDropdown()
+ public SettingsEnumDropdown()
{
if (!typeof(T).IsEnum)
- throw new InvalidOperationException("OptionsDropdown only supports enums as the generic type argument");
+ throw new InvalidOperationException("SettingsDropdown only supports enums as the generic type argument");
List> items = new List>();
foreach(var val in (T[])Enum.GetValues(typeof(T)))
diff --git a/osu.Game/Overlays/Options/OptionsFooter.cs b/osu.Game/Overlays/Settings/SettingsFooter.cs
similarity index 93%
rename from osu.Game/Overlays/Options/OptionsFooter.cs
rename to osu.Game/Overlays/Settings/SettingsFooter.cs
index c785f2d0c0..a9293ac2af 100644
--- a/osu.Game/Overlays/Options/OptionsFooter.cs
+++ b/osu.Game/Overlays/Settings/SettingsFooter.cs
@@ -12,9 +12,9 @@ using osu.Game.Graphics.Sprites;
using OpenTK;
using OpenTK.Graphics;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
- public class OptionsFooter : FillFlowContainer
+ public class SettingsFooter : FillFlowContainer
{
[BackgroundDependencyLoader]
private void load(OsuGameBase game, OsuColour colours, RulesetDatabase rulesets)
diff --git a/osu.Game/Overlays/Options/OptionsHeader.cs b/osu.Game/Overlays/Settings/SettingsHeader.cs
similarity index 90%
rename from osu.Game/Overlays/Options/OptionsHeader.cs
rename to osu.Game/Overlays/Settings/SettingsHeader.cs
index 8b97a607a2..8a118120de 100644
--- a/osu.Game/Overlays/Options/OptionsHeader.cs
+++ b/osu.Game/Overlays/Settings/SettingsHeader.cs
@@ -12,9 +12,9 @@ using osu.Game.Graphics.Sprites;
using osu.Game.Graphics.UserInterface;
using OpenTK.Graphics;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
- public class OptionsHeader : Container
+ public class SettingsHeader : Container
{
public SearchTextBox SearchTextBox;
@@ -25,7 +25,7 @@ namespace osu.Game.Overlays.Options
public Action Exit;
/// A reference to the current scroll position of the ScrollContainer we are contained within.
- public OptionsHeader(Func currentScrollOffset)
+ public SettingsHeader(Func currentScrollOffset)
{
this.currentScrollOffset = currentScrollOffset;
}
@@ -55,7 +55,7 @@ namespace osu.Game.Overlays.Options
Text = "settings",
TextSize = 40,
Margin = new MarginPadding {
- Left = OptionsOverlay.CONTENT_MARGINS,
+ Left = SettingsOverlay.CONTENT_MARGINS,
Top = Toolbar.Toolbar.TOOLTIP_HEIGHT
},
},
@@ -65,7 +65,7 @@ namespace osu.Game.Overlays.Options
Text = "Change the way osu! behaves",
TextSize = 18,
Margin = new MarginPadding {
- Left = OptionsOverlay.CONTENT_MARGINS,
+ Left = SettingsOverlay.CONTENT_MARGINS,
Bottom = 30
},
},
diff --git a/osu.Game/Overlays/Options/OptionLabel.cs b/osu.Game/Overlays/Settings/SettingsLabel.cs
similarity index 80%
rename from osu.Game/Overlays/Options/OptionLabel.cs
rename to osu.Game/Overlays/Settings/SettingsLabel.cs
index 3f3c569f3a..7d1364ef41 100644
--- a/osu.Game/Overlays/Options/OptionLabel.cs
+++ b/osu.Game/Overlays/Settings/SettingsLabel.cs
@@ -5,9 +5,9 @@ using osu.Framework.Allocation;
using osu.Framework.Graphics;
using osu.Game.Graphics;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
- internal class OptionLabel : OptionItem
+ internal class SettingsLabel : SettingsItem
{
protected override Drawable CreateControl() => null;
diff --git a/osu.Game/Overlays/Options/OptionsSection.cs b/osu.Game/Overlays/Settings/SettingsSection.cs
similarity index 88%
rename from osu.Game/Overlays/Options/OptionsSection.cs
rename to osu.Game/Overlays/Settings/SettingsSection.cs
index 5e36f79467..66b860402a 100644
--- a/osu.Game/Overlays/Options/OptionsSection.cs
+++ b/osu.Game/Overlays/Settings/SettingsSection.cs
@@ -13,9 +13,9 @@ using osu.Game.Graphics.Sprites;
using System.Collections.Generic;
using System.Linq;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
- public abstract class OptionsSection : Container, IHasFilterableChildren
+ public abstract class SettingsSection : Container, IHasFilterableChildren
{
protected FillFlowContainer FlowContent;
protected override Container Content => FlowContent;
@@ -35,7 +35,7 @@ namespace osu.Game.Overlays.Options
private readonly SpriteText headerLabel;
- protected OptionsSection()
+ protected SettingsSection()
{
Margin = new MarginPadding { Top = 20 };
AutoSizeAxes = Axes.Y;
@@ -57,8 +57,8 @@ namespace osu.Game.Overlays.Options
Padding = new MarginPadding
{
Top = 20 + border_size,
- Left = OptionsOverlay.CONTENT_MARGINS,
- Right = OptionsOverlay.CONTENT_MARGINS,
+ Left = SettingsOverlay.CONTENT_MARGINS,
+ Right = SettingsOverlay.CONTENT_MARGINS,
Bottom = 10,
},
RelativeSizeAxes = Axes.X,
diff --git a/osu.Game/Overlays/Options/OptionSlider.cs b/osu.Game/Overlays/Settings/SettingsSlider.cs
similarity index 76%
rename from osu.Game/Overlays/Options/OptionSlider.cs
rename to osu.Game/Overlays/Settings/SettingsSlider.cs
index 2cceb085a7..9ce4efdd52 100644
--- a/osu.Game/Overlays/Options/OptionSlider.cs
+++ b/osu.Game/Overlays/Settings/SettingsSlider.cs
@@ -6,14 +6,14 @@ using osu.Framework.Graphics.Primitives;
using osu.Framework.Graphics.UserInterface;
using osu.Game.Graphics.UserInterface;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
- public class OptionSlider : OptionSlider>
+ public class SettingsSlider : SettingsSlider>
where T : struct
{
}
- public class OptionSlider : OptionItem
+ public class SettingsSlider : SettingsItem
where T : struct
where U : SliderBar, new()
{
diff --git a/osu.Game/Overlays/Options/OptionsSubsection.cs b/osu.Game/Overlays/Settings/SettingsSubsection.cs
similarity index 87%
rename from osu.Game/Overlays/Options/OptionsSubsection.cs
rename to osu.Game/Overlays/Settings/SettingsSubsection.cs
index ff9e60c273..b4ce54cb75 100644
--- a/osu.Game/Overlays/Options/OptionsSubsection.cs
+++ b/osu.Game/Overlays/Settings/SettingsSubsection.cs
@@ -9,9 +9,9 @@ using osu.Game.Graphics.Sprites;
using System.Collections.Generic;
using System.Linq;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
- public abstract class OptionsSubsection : FillFlowContainer, IHasFilterableChildren
+ public abstract class SettingsSubsection : FillFlowContainer, IHasFilterableChildren
{
protected override Container Content => content;
@@ -29,7 +29,7 @@ namespace osu.Game.Overlays.Options
}
}
- protected OptionsSubsection()
+ protected SettingsSubsection()
{
RelativeSizeAxes = Axes.X;
AutoSizeAxes = Axes.Y;
diff --git a/osu.Game/Overlays/Options/OptionTextBox.cs b/osu.Game/Overlays/Settings/SettingsTextBox.cs
similarity index 74%
rename from osu.Game/Overlays/Options/OptionTextBox.cs
rename to osu.Game/Overlays/Settings/SettingsTextBox.cs
index 498f27796a..710330ad41 100644
--- a/osu.Game/Overlays/Options/OptionTextBox.cs
+++ b/osu.Game/Overlays/Settings/SettingsTextBox.cs
@@ -4,9 +4,9 @@
using osu.Framework.Graphics;
using osu.Game.Graphics.UserInterface;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
- public class OptionTextBox : OptionItem
+ public class SettingsTextBox : SettingsItem
{
protected override Drawable CreateControl() => new OsuTextBox();
}
diff --git a/osu.Game/Overlays/Options/Sidebar.cs b/osu.Game/Overlays/Settings/Sidebar.cs
similarity index 95%
rename from osu.Game/Overlays/Options/Sidebar.cs
rename to osu.Game/Overlays/Settings/Sidebar.cs
index eb489810ad..be93fdbac5 100644
--- a/osu.Game/Overlays/Options/Sidebar.cs
+++ b/osu.Game/Overlays/Settings/Sidebar.cs
@@ -10,7 +10,7 @@ using osu.Framework.Input;
using osu.Framework.Threading;
using osu.Game.Overlays.Toolbar;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
public class Sidebar : Container
{
diff --git a/osu.Game/Overlays/Options/SidebarButton.cs b/osu.Game/Overlays/Settings/SidebarButton.cs
similarity index 93%
rename from osu.Game/Overlays/Options/SidebarButton.cs
rename to osu.Game/Overlays/Settings/SidebarButton.cs
index 7c0049e8c7..766c6cf7e2 100644
--- a/osu.Game/Overlays/Options/SidebarButton.cs
+++ b/osu.Game/Overlays/Settings/SidebarButton.cs
@@ -12,7 +12,7 @@ using osu.Framework.Input;
using osu.Game.Graphics;
using osu.Game.Graphics.Sprites;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
public class SidebarButton : Container
{
@@ -23,8 +23,8 @@ namespace osu.Game.Overlays.Options
private readonly Container text;
public Action Action;
- private OptionsSection section;
- public OptionsSection Section
+ private SettingsSection section;
+ public SettingsSection Section
{
get
{
diff --git a/osu.Game/Overlays/Toolbar/ToolbarSettingsButton.cs b/osu.Game/Overlays/Toolbar/ToolbarSettingsButton.cs
index ae54b98aca..2eb8c15dcf 100644
--- a/osu.Game/Overlays/Toolbar/ToolbarSettingsButton.cs
+++ b/osu.Game/Overlays/Toolbar/ToolbarSettingsButton.cs
@@ -16,9 +16,9 @@ namespace osu.Game.Overlays.Toolbar
}
[BackgroundDependencyLoader]
- private void load(OptionsOverlay options)
+ private void load(SettingsOverlay settings)
{
- StateContainer = options;
+ StateContainer = settings;
}
}
}
\ No newline at end of file
diff --git a/osu.Game/Screens/Menu/ButtonSystem.cs b/osu.Game/Screens/Menu/ButtonSystem.cs
index b0d12cb5a1..2f418d2f88 100644
--- a/osu.Game/Screens/Menu/ButtonSystem.cs
+++ b/osu.Game/Screens/Menu/ButtonSystem.cs
@@ -82,7 +82,7 @@ namespace osu.Game.Screens.Menu
AutoSizeAxes = Axes.Both,
Children = new[]
{
- settingsButton = new Button(@"settings", @"options", FontAwesome.fa_gear, new Color4(85, 85, 85, 255), () => OnSettings?.Invoke(), -WEDGE_WIDTH, Key.O),
+ settingsButton = new Button(@"settings", @"settings", FontAwesome.fa_gear, new Color4(85, 85, 85, 255), () => OnSettings?.Invoke(), -WEDGE_WIDTH, Key.O),
backButton = new Button(@"back", @"back", FontAwesome.fa_osu_left_o, new Color4(51, 58, 94, 255), onBack, -WEDGE_WIDTH),
iconFacade = new Container //need a container to make the osu! icon flow properly.
{
diff --git a/osu.Game/Screens/Menu/Intro.cs b/osu.Game/Screens/Menu/Intro.cs
index 92032e5120..01659edd72 100644
--- a/osu.Game/Screens/Menu/Intro.cs
+++ b/osu.Game/Screens/Menu/Intro.cs
@@ -64,8 +64,8 @@ namespace osu.Game.Screens.Menu
[BackgroundDependencyLoader]
private void load(AudioManager audio, OsuConfigManager config)
{
- menuVoice = config.GetBindable(OsuConfig.MenuVoice);
- menuMusic = config.GetBindable(OsuConfig.MenuMusic);
+ menuVoice = config.GetBindable(OsuSetting.MenuVoice);
+ menuMusic = config.GetBindable(OsuSetting.MenuMusic);
bgm = audio.Track.Get(@"circles");
bgm.Looping = true;
diff --git a/osu.Game/Screens/Menu/MainMenu.cs b/osu.Game/Screens/Menu/MainMenu.cs
index c8a00e0671..71d020b0f2 100644
--- a/osu.Game/Screens/Menu/MainMenu.cs
+++ b/osu.Game/Screens/Menu/MainMenu.cs
@@ -66,7 +66,7 @@ namespace osu.Game.Screens.Menu
[BackgroundDependencyLoader]
private void load(OsuGame game, OsuConfigManager config, BeatmapDatabase beatmaps)
{
- menuMusic = config.GetBindable(OsuConfig.MenuMusic);
+ menuMusic = config.GetBindable(OsuSetting.MenuMusic);
LoadComponentAsync(background);
if (!menuMusic)
@@ -84,7 +84,7 @@ namespace osu.Game.Screens.Menu
}
}
- buttons.OnSettings = game.ToggleOptions;
+ buttons.OnSettings = game.ToggleSettings;
preloadSongSelect();
}
diff --git a/osu.Game/Screens/Play/HUDOverlay.cs b/osu.Game/Screens/Play/HUDOverlay.cs
index 12e2cb197e..1e57c2ba2a 100644
--- a/osu.Game/Screens/Play/HUDOverlay.cs
+++ b/osu.Game/Screens/Play/HUDOverlay.cs
@@ -67,7 +67,7 @@ namespace osu.Game.Screens.Play
[BackgroundDependencyLoader(true)]
private void load(OsuConfigManager config, NotificationManager notificationManager)
{
- showKeyCounter = config.GetBindable(OsuConfig.KeyOverlay);
+ showKeyCounter = config.GetBindable(OsuSetting.KeyOverlay);
showKeyCounter.ValueChanged += keyCounterVisibility =>
{
if (keyCounterVisibility)
@@ -77,7 +77,7 @@ namespace osu.Game.Screens.Play
};
showKeyCounter.TriggerChange();
- showHud = config.GetBindable(OsuConfig.ShowInterface);
+ showHud = config.GetBindable(OsuSetting.ShowInterface);
showHud.ValueChanged += hudVisibility =>
{
if (hudVisibility)
diff --git a/osu.Game/Screens/Play/Player.cs b/osu.Game/Screens/Play/Player.cs
index 7b910c11e5..de390b63b3 100644
--- a/osu.Game/Screens/Play/Player.cs
+++ b/osu.Game/Screens/Play/Player.cs
@@ -79,8 +79,8 @@ namespace osu.Game.Screens.Play
[BackgroundDependencyLoader(permitNulls: true)]
private void load(AudioManager audio, BeatmapDatabase beatmaps, OsuConfigManager config, OsuGame osu)
{
- dimLevel = config.GetBindable(OsuConfig.DimLevel);
- mouseWheelDisabled = config.GetBindable(OsuConfig.MouseDisableWheel);
+ dimLevel = config.GetBindable(OsuSetting.DimLevel);
+ mouseWheelDisabled = config.GetBindable(OsuSetting.MouseDisableWheel);
Ruleset rulesetInstance;
@@ -138,7 +138,7 @@ namespace osu.Game.Screens.Play
offsetClock = new FramedOffsetClock(decoupledClock);
- userAudioOffset = config.GetBindable(OsuConfig.AudioOffset);
+ userAudioOffset = config.GetBindable(OsuSetting.AudioOffset);
userAudioOffset.ValueChanged += v => offsetClock.Offset = v;
userAudioOffset.TriggerChange();
diff --git a/osu.Game/Screens/Play/PlayerInputManager.cs b/osu.Game/Screens/Play/PlayerInputManager.cs
index 9707ccbc35..f5e57f9e9d 100644
--- a/osu.Game/Screens/Play/PlayerInputManager.cs
+++ b/osu.Game/Screens/Play/PlayerInputManager.cs
@@ -40,7 +40,7 @@ namespace osu.Game.Screens.Play
[BackgroundDependencyLoader]
private void load(OsuConfigManager config)
{
- mouseDisabled = config.GetBindable(OsuConfig.MouseDisableButtons);
+ mouseDisabled = config.GetBindable(OsuSetting.MouseDisableButtons);
}
protected override void LoadComplete()
diff --git a/osu.Game/Screens/Select/BeatmapDetailAreaTabControl.cs b/osu.Game/Screens/Select/BeatmapDetailAreaTabControl.cs
index 51ec6f7707..e3c95d42a1 100644
--- a/osu.Game/Screens/Select/BeatmapDetailAreaTabControl.cs
+++ b/osu.Game/Screens/Select/BeatmapDetailAreaTabControl.cs
@@ -35,7 +35,7 @@ namespace osu.Game.Screens.Select
{
modsCheckbox.AccentColour = tabs.AccentColour = colour.YellowLight;
- selectedTab = config.GetBindable(OsuConfig.BeatmapDetailTab);
+ selectedTab = config.GetBindable(OsuSetting.BeatmapDetailTab);
tabs.Current.BindTo(selectedTab);
tabs.Current.TriggerChange();
diff --git a/osu.Game/Screens/Select/Options/BeatmapOptionsButton.cs b/osu.Game/Screens/Select/Options/BeatmapOptionsButton.cs
index 965ea12fe2..0935bb3686 100644
--- a/osu.Game/Screens/Select/Options/BeatmapOptionsButton.cs
+++ b/osu.Game/Screens/Select/Options/BeatmapOptionsButton.cs
@@ -1,9 +1,6 @@
// Copyright (c) 2007-2017 ppy Pty Ltd .
// Licensed under the MIT Licence - https://raw.githubusercontent.com/ppy/osu/master/LICENCE
-using OpenTK;
-using OpenTK.Graphics;
-using OpenTK.Input;
using osu.Framework.Extensions.Color4Extensions;
using osu.Framework.Graphics;
using osu.Framework.Graphics.Containers;
@@ -12,6 +9,9 @@ using osu.Framework.Graphics.Sprites;
using osu.Framework.Input;
using osu.Game.Graphics;
using osu.Game.Graphics.Sprites;
+using OpenTK;
+using OpenTK.Graphics;
+using OpenTK.Input;
namespace osu.Game.Screens.Select.Options
{
diff --git a/osu.Game/Screens/Select/Options/BeatmapOptionsOverlay.cs b/osu.Game/Screens/Select/Options/BeatmapOptionsOverlay.cs
index 77001950f6..c064a0272e 100644
--- a/osu.Game/Screens/Select/Options/BeatmapOptionsOverlay.cs
+++ b/osu.Game/Screens/Select/Options/BeatmapOptionsOverlay.cs
@@ -4,14 +4,14 @@
using System;
using System.Collections.Generic;
using System.Linq;
-using OpenTK;
-using OpenTK.Graphics;
-using OpenTK.Input;
using osu.Framework.Extensions.Color4Extensions;
using osu.Framework.Graphics;
using osu.Framework.Graphics.Containers;
using osu.Framework.Graphics.Sprites;
using osu.Game.Graphics;
+using OpenTK;
+using OpenTK.Graphics;
+using OpenTK.Input;
namespace osu.Game.Screens.Select.Options
{
diff --git a/osu.Game/osu.Game.csproj b/osu.Game/osu.Game.csproj
index ee6153dc55..1f866f0e17 100644
--- a/osu.Game/osu.Game.csproj
+++ b/osu.Game/osu.Game.csproj
@@ -79,8 +79,8 @@
-
-
+
+
@@ -207,13 +207,13 @@
-
-
+
+
-
-
-
-
+
+
+
+
@@ -278,6 +278,8 @@
+
+
@@ -313,7 +315,7 @@
-
+
@@ -346,39 +348,39 @@
-
-
-
+
+
+
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
-
-
-
-
-
+
+
+
+
+
+
@@ -410,8 +412,6 @@
-
-
diff --git a/osu.Game/Overlays/Options/OptionItem.cs b/osu.Game/Overlays/Settings/SettingsItem.cs
similarity index 89%
rename from osu.Game/Overlays/Options/OptionItem.cs
rename to osu.Game/Overlays/Settings/SettingsItem.cs
index 2124796089..a40f895e0a 100644
--- a/osu.Game/Overlays/Options/OptionItem.cs
+++ b/osu.Game/Overlays/Settings/SettingsItem.cs
@@ -10,9 +10,9 @@ using osu.Framework.Graphics.Sprites;
using osu.Framework.Graphics.UserInterface;
using osu.Game.Graphics.Sprites;
-namespace osu.Game.Overlays.Options
+namespace osu.Game.Overlays.Settings
{
- public abstract class OptionItem : FillFlowContainer, IFilterable
+ public abstract class SettingsItem : FillFlowContainer, IFilterable
{
protected abstract Drawable CreateControl();
@@ -37,7 +37,7 @@ namespace osu.Game.Overlays.Options
}
}
// hold a reference to the provided bindable so we don't have to in every options section.
private Bindable bindable;
public Bindable Bindable
@@ -65,7 +65,7 @@ namespace osu.Game.Overlays.Options
}
}
- protected OptionItem()
+ protected SettingsItem()
{
RelativeSizeAxes = Axes.X;
AutoSizeAxes = Axes.Y;
@@ -37,7 +37,7 @@ namespace osu.Game.Overlays.Options
}
}
- // hold a reference to the provided bindable so we don't have to in every options section.
+ // hold a reference to the provided bindable so we don't have to in every settings section.
private Bindable bindable;
public Bindable Bindable
diff --git a/osu.Game/Overlays/OptionsOverlay.cs b/osu.Game/Overlays/SettingsOverlay.cs
similarity index 86%
rename from osu.Game/Overlays/OptionsOverlay.cs
rename to osu.Game/Overlays/SettingsOverlay.cs
index 6d1a3a64fc..e3fbf12df3 100644
--- a/osu.Game/Overlays/OptionsOverlay.cs
+++ b/osu.Game/Overlays/SettingsOverlay.cs
@@ -8,14 +8,14 @@ using osu.Framework.Graphics;
using osu.Framework.Graphics.Containers;
using osu.Framework.Graphics.Primitives;
using osu.Framework.Graphics.Sprites;
-using osu.Game.Overlays.Options;
+using osu.Game.Overlays.Settings;
using System;
-using osu.Game.Overlays.Options.Sections;
+using osu.Game.Overlays.Settings.Sections;
using osu.Framework.Input;
namespace osu.Game.Overlays
{
- public class OptionsOverlay : FocusedOverlayContainer
+ public class SettingsOverlay : FocusedOverlayContainer
{
internal const float CONTENT_MARGINS = 10;
@@ -30,17 +30,17 @@ namespace osu.Game.Overlays
private ScrollContainer scrollContainer;
private Sidebar sidebar;
private SidebarButton[] sidebarButtons;
- private OptionsSection[] sections;
+ private SettingsSection[] sections;
- private OptionsHeader header;
+ private SettingsHeader header;
- private OptionsFooter footer;
+ private SettingsFooter footer;
private SearchContainer searchContainer;
private float lastKnownScroll;
- public OptionsOverlay()
+ public SettingsOverlay()
{
RelativeSizeAxes = Axes.Y;
AutoSizeAxes = Axes.X;
@@ -49,7 +49,7 @@ namespace osu.Game.Overlays
[BackgroundDependencyLoader(permitNulls: true)]
private void load(OsuGame game)
{
- sections = new OptionsSection[]
+ sections = new SettingsSection[]
{
new GeneralSection(),
new GraphicsSection(),
@@ -84,8 +84,8 @@ namespace osu.Game.Overlays
Direction = FillDirection.Vertical,
Children = sections,
},
- footer = new OptionsFooter(),
- header = new OptionsHeader(() => scrollContainer.Current)
+ footer = new SettingsFooter(),
+ header = new SettingsHeader(() => scrollContainer.Current)
{
Exit = Hide,
},
@@ -114,7 +114,7 @@ namespace osu.Game.Overlays
{
base.UpdateAfterChildren();
//we need to update these manually because we can't put the OptionsHeader inside the SearchContainer (due to its anchoring).
searchContainer.Y = header.DrawHeight;
footer.Y = searchContainer.Y + searchContainer.DrawHeight;
}
@@ -128,10 +128,10 @@ namespace osu.Game.Overlays
{
lastKnownScroll = currentScroll;
- OptionsSection bestCandidate = null;
+ SettingsSection bestCandidate = null;
float bestDistance = float.MaxValue;
- foreach (OptionsSection section in sections)
+ foreach (SettingsSection section in sections)
{
float distance = Math.Abs(scrollContainer.GetChildPosInContent(section) - currentScroll);
if (distance < bestDistance)
@@ -114,7 +114,7 @@ namespace osu.Game.Overlays
{
base.UpdateAfterChildren();
- //we need to update these manually because we can't put the OptionsHeader inside the SearchContainer (due to its anchoring).
+ //we need to update these manually because we can't put the SettingsHeader inside the SearchContainer (due to its anchoring).
searchContainer.Y = header.DrawHeight;
footer.Y = searchContainer.Y + searchContainer.DrawHeight;